---
title: requestPayment 요청 형식
description: requestPayment 호출 시 사용되는 파라미터의 형식을 확인할 수 있습니다.
targetVersions:
  - v2
versionVariants:
  v1: /sdk/ko/v1-sdk/javascript-sdk/payrq
---

## `requestPayment` 요청 데이터 정의

- request: PaymentRequest

  [definition link](https://developers.portone.io/schema/browser-sdk.yml#/resources/request/PaymentRequest)
